@@ -1,7 +1,5 @@
 import click
 
-from ploomber.cloud import api
-
 
 @click.group()
 def cli():
@@ -11,11 +9,14 @@ def cli():
 
 
 @cli.command()
+@click.argument('runid')
 @click.argument('reason')
-def mark_failed(reason):
+def mark_failed(runid, reason):
     """Mark latest run as failed if passed something different than "none"
     """
-    api.run_latest_failed(reason)
+    from ploomber.cloud.api import PloomberCloudAPI
+    api = PloomberCloudAPI()
+    api.run_failed(runid, reason)
 
 
 if __name__ == '__main__':
